summaryrefslogtreecommitdiffstats
path: root/kalarm/timeselector.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
commit7be55ffa061c026e35e2d6a0effe1161ddb0d41f (patch)
tree8474f9b444b2756228600050f07a7ff25de532b2 /kalarm/timeselector.cpp
parentf587f20a6d09f1729dd0a8c1cd8ee0110aec7451 (diff)
downloadtdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.tar.gz
tdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1157655 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalarm/timeselector.cpp')
-rw-r--r--kalarm/timeselector.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/kalarm/timeselector.cpp b/kalarm/timeselector.cpp
index 0bfc142d..9ec5c981 100644
--- a/kalarm/timeselector.cpp
+++ b/kalarm/timeselector.cpp
@@ -20,10 +20,10 @@
#include "kalarm.h"
-#include <qlayout.h>
-#include <qlabel.h>
-#include <qhbox.h>
-#include <qwhatsthis.h>
+#include <tqlayout.h>
+#include <tqlabel.h>
+#include <tqhbox.h>
+#include <tqwhatsthis.h>
#include <klocale.h>
#include <kdialog.h>
@@ -33,35 +33,35 @@
#include "timeselector.moc"
-TimeSelector::TimeSelector(const QString& selectText, const QString& postfix, const QString& selectWhatsThis,
- const QString& valueWhatsThis, bool allowHourMinute, QWidget* parent, const char* name)
- : QFrame(parent, name),
+TimeSelector::TimeSelector(const TQString& selectText, const TQString& postfix, const TQString& selectWhatsThis,
+ const TQString& valueWhatsThis, bool allowHourMinute, TQWidget* parent, const char* name)
+ : TQFrame(parent, name),
mLabel(0),
mReadOnly(false)
{
- setFrameStyle(QFrame::NoFrame);
- QVBoxLayout* topLayout = new QVBoxLayout(this, 0, KDialog::spacingHint());
- QHBoxLayout* layout = new QHBoxLayout(topLayout, KDialog::spacingHint());
+ setFrameStyle(TQFrame::NoFrame);
+ TQVBoxLayout* topLayout = new TQVBoxLayout(this, 0, KDialog::spacingHint());
+ TQHBoxLayout* layout = new TQHBoxLayout(topLayout, KDialog::spacingHint());
mSelect = new CheckBox(selectText, this);
mSelect->setFixedSize(mSelect->sizeHint());
- connect(mSelect, SIGNAL(toggled(bool)), SLOT(selectToggled(bool)));
- QWhatsThis::add(mSelect, selectWhatsThis);
+ connect(mSelect, TQT_SIGNAL(toggled(bool)), TQT_SLOT(selectToggled(bool)));
+ TQWhatsThis::add(mSelect, selectWhatsThis);
layout->addWidget(mSelect);
- QHBox* box = new QHBox(this); // to group widgets for QWhatsThis text
+ TQHBox* box = new TQHBox(this); // to group widgets for TQWhatsThis text
box->setSpacing(KDialog::spacingHint());
layout->addWidget(box);
mPeriod = new TimePeriod(allowHourMinute, box);
mPeriod->setFixedSize(mPeriod->sizeHint());
mPeriod->setSelectOnStep(false);
- connect(mPeriod, SIGNAL(valueChanged(int)), SLOT(periodChanged(int)));
+ connect(mPeriod, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(periodChanged(int)));
mSelect->setFocusWidget(mPeriod);
mPeriod->setEnabled(false);
if (!postfix.isEmpty())
{
- mLabel = new QLabel(postfix, box);
- QWhatsThis::add(box, valueWhatsThis);
+ mLabel = new TQLabel(postfix, box);
+ TQWhatsThis::add(box, valueWhatsThis);
mLabel->setEnabled(false);
}
}